/*
Copyright (c) 2006-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#include "animMover.h"

// Sprite Animation Mover

CSpriteAnimMover::CSpriteAnimMover( TInt aPriority, TInt aMicroSeconds, CSpriteAnimation* aSpriteAnim )
: CActive( aPriority ), iMicroSeconds( aMicroSeconds ), iSpriteAnim( aSpriteAnim )
	{
		
	CActiveScheduler::Add( this );
	
	iTimer.CreateLocal();
	iTimer.After( iStatus, aMicroSeconds );
	SetActive();
	}
	
		
CSpriteAnimMover::~CSpriteAnimMover()
	{
	iTimer.Close();	
	}

	
void CSpriteAnimMover::DoCancel()
	{
	iTimer.Cancel();		
	}

	
void CSpriteAnimMover::RunL()
	{
	
	if( !iSpriteAnim )
		{
		User::Leave( KErrNotReady );	
		}

	if( iX++ <= KXDeflectionTerminalValue )
		{
		iSpriteAnim->SetPosition( TPoint(iX, iY) );	
		}
	else
		{
		
		Cancel();
		iSpriteAnim->SetPosition( TPoint(KAnimExSpriteInitPosX, KAnimExSpriteInitPosY ) );	
		}
		
	iTimer.After( iStatus, iMicroSeconds );	
	SetActive();
	}
	
	
	
// Basic Animation Mover

CBasicAnimMover::CBasicAnimMover( TInt aPriority, TInt aMicroSeconds, CBasicAnimation* aBasicAnim )
: CActive( aPriority ), iMicroSeconds( aMicroSeconds ), iBasicAnim( aBasicAnim ), iX( 0 ), iY( 0 )
	{
		
	CActiveScheduler::Add( this );
	
	iTimer.CreateLocal();
	iTimer.After( iStatus, aMicroSeconds );
	SetActive();
	}
	
	CBasicAnimMover::~CBasicAnimMover()
	{
	
	iTimer.Close();	
	}

void CBasicAnimMover::DoCancel()
	{
	
	iTimer.Cancel();		
	}

void CBasicAnimMover::RunL()
	{
	
	if( !iBasicAnim )
		{
		User::Leave( KErrNotReady );	
		}
	
	
	if( iX < KXDeflectionTerminalValue )
		{
		iY =TInt(KYDeflectionOffset + KYDeflectionMultiplier*sin( iX++ ));	
		iBasicAnim->SetPosition( TPoint(iX, iY) );
		
		iX += KXDeflectionIncrement;	
		}
	else
		{
		
		Cancel();
		iBasicAnim->SetPosition( TPoint(KAnimExBasicInitPosX, KAnimExBasicInitPosY) );			
		}
		
		
	iTimer.After( iStatus, iMicroSeconds );	
	SetActive();
	}
